from django.views.generic import ListView, DetailView
from django.views.generic.edit import CreateView, UpdateView, DeleteView
from django.contrib.auth.mixins import LoginRequiredMixin

from guild.models import Adventure, PlaySession


class AdventureListView(LoginRequiredMixin, ListView):
    model = Adventure
    context_object_name = "adventures"


class CreateAdventureView(LoginRequiredMixin, CreateView):
    model = Adventure
    fields = ["name", "description", "master"]


class AdventureDetailView(LoginRequiredMixin, DetailView):
    model = Adventure

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["sessions"] = PlaySession.objects.filter(
            adventure=self.object
        ).order_by("date")
        return context


class AdventureUpdateView(LoginRequiredMixin, UpdateView):
    model = Adventure
    fields = ["name", "description", "master"]


class AdventureDeleteView(LoginRequiredMixin, DeleteView):
    model = Adventure
    success_url = "/"
